AutoGen Studio [Beta]Build Multi-Agent Apps

#

Search
Galleries1
All Galleries
Default Component Gallery
v1.0.0
15 components
2 days agodefault
Gallery items marked as default (
) are available in the builder by default.
Galleries
Default Component Gallery

# Default Component Gallery

A default gallery containing basic components for human-in-loop conversations

AutoGen Team

15 components
v1.0.0
human-in-loop
assistant
web agents
3 teams
autogen_agentchat.teams.RoundRobinGroupChat
Default Team

A single AssistantAgent (with a calculator tool) in a RoundRobinGroupChat team.

autogen_agentchat.teams.SelectorGroupChat
Web Agent Team (Operator)

A group chat team that have participants takes turn to publish a message to all, using a ChatCompletion model to select the next speaker after eac...

autogen_agentchat.teams.SelectorGroupChat
Deep Research Team

A team that performs deep research using web searches, verification, and summarization.

4 agents
autogen_agentchat.agents.AssistantAgent
AssistantAgent

An agent that provides assistance with ability to use tools.

autogen_ext.agents.web_surfer.MultimodalWebSurfer
MultimodalWebSurfer

MultimodalWebSurfer is a multimodal agent that acts as a web surfer that can search the web and visit web pages.

autogen_agentchat.agents.AssistantAgent
AssistantAgent

An agent that provides assistance with tool use.

autogen_agentchat.agents.UserProxyAgent
UserProxyAgent

An agent that can represent a human user through an input function.

6 tools
autogen_core.tools.FunctionTool
Calculator Tool

A tool that performs basic arithmetic operations (addition, subtraction, multiplication, division).

autogen_core.tools.FunctionTool
Image Generation Tool

A tool that generates images based on a text description using OpenAI's DALL-E model. Note: Requires OpenAI API key to function.

autogen_core.tools.FunctionTool
PDF Generation Tool

A tool that generates a PDF file from a list of images.Requires the PyFPDF and pillow library to function.

autogen_core.tools.FunctionTool
Fetch Webpage Tool

A tool that fetches the content of a webpage and converts it to markdown. Requires the requests and beautifulsoup4 library to function.

autogen_core.tools.FunctionTool
Bing Search Tool

A tool that performs Bing searches using the Bing Web Search API. Requires the requests library, BING_SEARCH_KEY env variable to function.

autogen_core.tools.FunctionTool
Google Search Tool

A tool that performs Google searches using the Google Custom Search API. Requires the requests library, [GOOGLE_API_KEY, GOOGLE_CSE_ID] to be set, en...

2 models
autogen_ext.models.openai.OpenAIChatCompletionClient
OpenAIChatCompletionClient

Chat completion client for OpenAI hosted models.

autogen_ext.models.openai.OpenAIChatCompletionClient
Mistral-7B vllm

Example on how to use the OpenAIChatCopletionClient with local models (Ollama, vllm etc).

3 terminations
autogen_agentchat.conditions.TextMentionTermination
TextMentionTermination

Terminate the conversation if a specific text is mentioned.

autogen_agentchat.conditions.MaxMessageTermination
MaxMessageTermination

Terminate the conversation after a maximum number of messages have been exchanged.

autogen_agentchat.base.OrTerminationCondition
OrTerminationCondition
Maintained by the AutoGen Team.